@@ -2,4 +2,4 @@ from twython import Twython
 
 # Requires Authentication as of Twitter API v1.1
 twitter = Twython(APP_KEY, APP_SECRET, OAUTH_TOKEN, OAUTH_TOKEN_SECRET)
-twitter.updateProfileImage('myImage.png')
+twitter.update_profile_image('myImage.png')
